@@ -20,7 +20,7 @@ has options => sub {
 };
 has [qw(password username)] => '';
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 sub db {
   my $self = shift;
@@ -96,7 +96,7 @@ Mojo::Pg - Mojolicious ♥ PostgreSQL
 
   # Create a table
   my $pg = Mojo::Pg->new('postgresql://postgres@/test');
-  $pg->db->do('create table if not exists names (name varchar(255))');
+  $pg->db->do('create table if not exists names (name text)');
 
   # Insert a few rows
   my $db = $pg->db;
