@@ -266,7 +266,7 @@ Disconnect L</"dbh"> and prevent it from getting cached again.
 
 =head2 do
 
-  $db = $db->do('create table foo (bar varchar(255))');
+  $db = $db->do('create table foo (bar text)');
 
 Execute a statement and discard its result.
 
